@@ -8,7 +8,11 @@ struct encoding* encodingp=NULL;
 struct encoding* InitEncoding(char* encoding) 
 {
   char *pos,*max,*buf,*enc_file =
+#ifdef HAVE_KPSE_ENC_FORMATS
+    kpse_find_file(encoding,kpse_enc_format,false);
+#else
     kpse_find_file(encoding,kpse_tex_ps_header_format,false);
+#endif
   int encfd,i;
   struct encoding* encp=NULL;
   struct stat stat;
@@ -27,7 +31,7 @@ struct encoding* InitEncoding(char* encoding)
     Warning("cannot mmap encoding <%s> !\n",enc_file);
     return(NULL);
   }
-  if ((encp = calloc(sizeof(struct encoding)+strlen(encoding)
+  if ((encp = calloc(sizeof(struct encoding)+strlen(encoding)+1
 		     +stat.st_size,1))==NULL) {
     Warning("cannot alloc space for encoding",enc_file);
     return(NULL);
@@ -38,6 +42,18 @@ struct encoding* InitEncoding(char* encoding)
   max=encmmap+stat.st_size;
   buf=encp->name+strlen(encoding)+1;
 #define SKIPCOMMENT(x) if (*x=='%') while (x<max && *x!='\n') x++;
+  while(pos<max && *pos!='/') {
+    SKIPCOMMENT(pos);
+    pos++;
+  }
+  pos++;
+  encp->charname[256]=buf;
+  while(pos<max && *pos!='[' 
+	&& *pos!=' ' && *pos!='\t' && *pos!='\n' && *pos!='%') 
+    *buf++=*pos++;
+  *buf++='\0';
+  DEBUG_PRINT(DEBUG_ENC,("\n  PS ENCODING '%s'",
+			 encp->charname[256])); 
   while (pos < max && *pos!='[') {
     SKIPCOMMENT(pos);
     pos++;
@@ -72,6 +88,7 @@ struct encoding* FindEncoding(char* encoding)
 {
   struct encoding *temp=encodingp;
 
+  //  printf("{%s} \n",encoding);
   while(temp!=NULL && strcmp(encoding,temp->name)!=0) 
     temp=temp->next;
   if (temp==NULL) {
