@@ -131,17 +131,18 @@ void SetSpecial(char * special, int32_t length, int32_t hh, int32_t vv)
   token = strtok(buffer," ");
   /********************** Color specials ***********************/
   if (strcmp(token,"background")==0) {
-    token = strtok(NULL," ");
+    token = strtok(NULL,"\0");
     background(token);
     return;
   }
   if (strcmp(token,"color")==0) {
-    token = strtok(NULL," ");
-    if (strcmp(token,"push")==0) {
-      token = strtok(NULL," ");
+    token = strtok(NULL,"\0");
+    if (strncmp(token,"push",4)==0) {
+      token = strtok(token," ");
+      token = strtok(NULL,"\0");
       pushcolor(token);
     } else {
-      if (strcmp(token,"pop")==0)
+      if (strncmp(token,"pop",3)==0)
 	popcolor();
       else 
 	resetcolorstack(token);
@@ -308,15 +309,15 @@ void SetSpecial(char * special, int32_t length, int32_t hh, int32_t vv)
     return;
   }
 
-  if (strncmp(token,"header=",7)==0) { /* header, ignored */
+  if (strncmp(token,"header=",7)==0 || token[0]=='!') { /* header, ignored */
     if ( page_imagep != NULL )
-      Warning("at (%ld,%ld) unimplemented \\special{%.*s}.",
+      Warning("at (%ld,%ld) ignored header \\special{%.*s}.",
 	      hh, vv, length,special);
     return;
   }
-  if (strncmp(token,"!",7)==0) { /* literal PostScript, ignored */
+  if (strncmp(token,"src:",4)==0) { /* source special */
     if ( page_imagep != NULL )
-      Warning("at (%ld,%ld) unimplemented \\special{%.*s}.",
+      Message(BE_NONQUIET," at (%ld,%ld) source \\special{%.*s}",
 	      hh, vv, length,special);
     return;
   }
